@@ -7,11 +7,11 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
@@ -36,6 +36,7 @@ func TestExecute(t *testing.T) {
 		{"archive", "tar", artifact.UploadableArchive},
 		{"ubinary", "ubi", artifact.UploadableBinary},
 		{"checksum", "sum", artifact.Checksum},
+		{"metadata", "json", artifact.Metadata},
 		{"signature", "sig", artifact.Signature},
 		{"signature", "pem", artifact.Certificate},
 	} {
@@ -186,6 +187,30 @@ func TestExecute(t *testing.T) {
 			nil,
 			nil,
 		},
+		{
+			"include metadata",
+			[]config.Publisher{
+				{
+					Name: "test",
+					Meta: true,
+					Cmd:  MockCmd + " {{ .ArtifactName }}",
+					Env: []string{
+						MarshalMockEnv(&MockData{
+							AnyOf: []MockCall{
+								{ExpectedArgs: []string{"a.deb"}, ExitCode: 0, ExpectedEnv: osEnv()},
+								{ExpectedArgs: []string{"a.ubi"}, ExitCode: 0, ExpectedEnv: osEnv()},
+								{ExpectedArgs: []string{"a.tar"}, ExitCode: 0, ExpectedEnv: osEnv()},
+								{ExpectedArgs: []string{"a.json"}, ExitCode: 0, ExpectedEnv: osEnv()},
+								{ExpectedArgs: []string{"foo/bar"}, ExitCode: 0, ExpectedEnv: osEnv()},
+								{ExpectedArgs: []string{"foo/bar:amd64"}, ExitCode: 0, ExpectedEnv: osEnv()},
+							},
+						}),
+					},
+				},
+			},
+			nil,
+			nil,
+		},
 		{
 			"include signatures",
 			[]config.Publisher{
