@@ -344,6 +344,10 @@ func getChangeloger(ctx *context.Context) (changeloger, error) {
 	case useGit, "":
 		return gitChangeloger{}, nil
 	case useGitLab, useGitea, useGitHub:
+		if ctx.Git.PreviousTag == "" {
+			log.Warnf("there's no previous tag, using 'git' instead of '%s'", ctx.Config.Changelog.Use)
+			return gitChangeloger{}, nil
+		}
 		return newSCMChangeloger(ctx)
 	case useGitHubNative:
 		return newGithubChangeloger(ctx)
