@@ -6,11 +6,11 @@ import (
 	"syscall"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -187,7 +187,7 @@ func TestEmptyGithubEnvFile(t *testing.T) {
 	})
 	err = Pipe{}.Run(ctx)
 	require.ErrorIs(t, err, syscall.EACCES)
-	require.Contains(t, err.Error(), "failed to load github token")
+	require.ErrorContains(t, err, "failed to load github token")
 }
 
 func TestEmptyGitlabEnvFile(t *testing.T) {
@@ -202,7 +202,7 @@ func TestEmptyGitlabEnvFile(t *testing.T) {
 	})
 	err = Pipe{}.Run(ctx)
 	require.ErrorIs(t, err, syscall.EACCES)
-	require.Contains(t, err.Error(), "failed to load gitlab token")
+	require.ErrorContains(t, err, "failed to load gitlab token")
 }
 
 func TestEmptyGiteaEnvFile(t *testing.T) {
@@ -217,7 +217,7 @@ func TestEmptyGiteaEnvFile(t *testing.T) {
 	})
 	err = Pipe{}.Run(ctx)
 	require.ErrorIs(t, err, syscall.EACCES)
-	require.Contains(t, err.Error(), "failed to load gitea token")
+	require.ErrorContains(t, err, "failed to load gitea token")
 }
 
 func TestInvalidEnvChecksSkipped(t *testing.T) {
