@@ -6,12 +6,12 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -665,9 +665,15 @@ func TestSkip(t *testing.T) {
 				SkipUpload: "{{ .Env.FOO }}",
 			},
 		})
+		ctx.Artifacts.Add(&artifact.Artifact{
+			Name: "a",
+			Path: "./doc.go",
+			Type: artifact.UploadableFile,
+		})
 		client := &client.Mock{}
 		testlib.AssertSkipped(t, doPublish(ctx, client))
 		require.True(t, client.CreatedRelease)
+		require.True(t, client.ReleasePublished)
 		require.False(t, client.UploadedFile)
 	})
 
@@ -677,15 +683,30 @@ func TestSkip(t *testing.T) {
 				SkipUpload: "true",
 			},
 		})
+		ctx.Artifacts.Add(&artifact.Artifact{
+			Name: "a",
+			Path: "./doc.go",
+			Type: artifact.UploadableFile,
+		})
 		client := &client.Mock{}
 		testlib.AssertSkipped(t, doPublish(ctx, client))
 		require.True(t, client.CreatedRelease)
+		require.True(t, client.ReleasePublished)
 		require.False(t, client.UploadedFile)
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		b, err := Pipe{}.Skip(testctx.New())
-		require.NoError(t, err)
-		require.False(t, b)
+		ctx := testctx.New()
+		ctx.Artifacts.Add(&artifact.Artifact{
+			Name: "a",
+			Path: "./doc.go",
+			Type: artifact.UploadableFile,
+		})
+
+		client := &client.Mock{}
+		require.NoError(t, doPublish(ctx, client))
+		require.True(t, client.CreatedRelease)
+		require.True(t, client.ReleasePublished)
+		require.True(t, client.UploadedFile)
 	})
 }
