@@ -8,19 +8,17 @@ import (
 	"os"
 	"path"
 	"path/filepath"
-	"reflect"
 	"strings"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/commitauthor"
-	"github.com/goreleaser/goreleaser/internal/deprecate"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/commitauthor"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 // ErrIncorrectArchiveCount happens when a given filter evaluates 0 or more
@@ -63,7 +61,7 @@ type Pipe struct{}
 func (Pipe) String() string        { return "scoop manifests" }
 func (Pipe) ContinueOnError() bool { return true }
 func (Pipe) Skip(ctx *context.Context) bool {
-	return skips.Any(ctx, skips.Scoop) || (ctx.Config.Scoop.Repository.Name == "" && len(ctx.Config.Scoops) == 0)
+	return skips.Any(ctx, skips.Scoop) || len(ctx.Config.Scoops) == 0
 }
 
 // Run creates the scoop manifest locally.
@@ -86,21 +84,11 @@ func (Pipe) Publish(ctx *context.Context) error {
 
 // Default sets the pipe defaults.
 func (Pipe) Default(ctx *context.Context) error {
-	if !reflect.DeepEqual(ctx.Config.Scoop.Bucket, config.RepoRef{}) ||
-		!reflect.DeepEqual(ctx.Config.Scoop.Repository, config.RepoRef{}) {
-		deprecate.Notice(ctx, "scoop")
-		ctx.Config.Scoops = append(ctx.Config.Scoops, ctx.Config.Scoop)
-	}
-
 	for i := range ctx.Config.Scoops {
 		scoop := &ctx.Config.Scoops[i]
 		if scoop.Name == "" {
 			scoop.Name = ctx.Config.ProjectName
 		}
-		if scoop.Folder != "" {
-			deprecate.Notice(ctx, "scoops.folder")
-			scoop.Directory = scoop.Folder
-		}
 		scoop.CommitAuthor = commitauthor.Default(scoop.CommitAuthor)
 		if scoop.CommitMessageTemplate == "" {
 			scoop.CommitMessageTemplate = "Scoop update for {{ .ProjectName }} version {{ .Tag }}"
@@ -108,10 +96,6 @@ func (Pipe) Default(ctx *context.Context) error {
 		if scoop.Goamd64 == "" {
 			scoop.Goamd64 = "v1"
 		}
-		if !reflect.DeepEqual(scoop.Bucket, config.RepoRef{}) {
-			scoop.Repository = scoop.Bucket
-			deprecate.Notice(ctx, "scoops.bucket")
-		}
 	}
 	return nil
 }
@@ -399,7 +383,7 @@ func dataFor(ctx *context.Context, scoop config.Scoop, cl client.ReleaseURLTempl
 }
 
 func binaries(a artifact.Artifact) ([]string, error) {
-	// nolint: prealloc
+	//nolint:prealloc
 	var result []string
 	wrap := artifact.ExtraOr(a, artifact.ExtraWrappedIn, "")
 	bins, err := artifact.Extra[[]string](a, artifact.ExtraBinaries)
