@@ -369,6 +369,8 @@ type Ko struct {
 	WorkingDir          string            `yaml:"working_dir,omitempty" json:"working_dir,omitempty"`
 	BaseImage           string            `yaml:"base_image,omitempty" json:"base_image,omitempty"`
 	Labels              map[string]string `yaml:"labels,omitempty" json:"labels,omitempty"`
+	Annotations         map[string]string `yaml:"annotations,omitempty" json:"annotations,omitempty"`
+	User                string            `yaml:"user,omitempty" json:"user,omitempty"`
 	Repository          string            `yaml:"repository,omitempty" json:"repository,omitempty"`
 	Platforms           []string          `yaml:"platforms,omitempty" json:"platforms,omitempty"`
 	Tags                []string          `yaml:"tags,omitempty" json:"tags,omitempty"`
@@ -418,11 +420,15 @@ type BuildHooks struct { // renamed on pro
 
 // IgnoredBuild represents a build ignored by the user.
 type IgnoredBuild struct {
-	Goos    string `yaml:"goos,omitempty" json:"goos,omitempty"`
-	Goarch  string `yaml:"goarch,omitempty" json:"goarch,omitempty"`
-	Goarm   string `yaml:"goarm,omitempty" json:"goarm,omitempty" jsonschema:"oneof_type=string;integer"`
-	Gomips  string `yaml:"gomips,omitempty" json:"gomips,omitempty"`
-	Goamd64 string `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
+	Goos      string `yaml:"goos,omitempty" json:"goos,omitempty"`
+	Goarch    string `yaml:"goarch,omitempty" json:"goarch,omitempty"`
+	Goamd64   string `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
+	Go386     string `yaml:"go386,omitempty" json:"go386,omitempty"`
+	Goarm     string `yaml:"goarm,omitempty" json:"goarm,omitempty" jsonschema:"oneof_type=string;integer"`
+	Goarm64   string `yaml:"goarm64,omitempty" json:"goarm64,omitempty"`
+	Gomips    string `yaml:"gomips,omitempty" json:"gomips,omitempty"`
+	Goppc64   string `yaml:"goppc64,omitempty" json:"goppc64,omitempty"`
+	Goriscv64 string `yaml:"goriscv64,omitempty" json:"goriscv64,omitempty"`
 }
 
 // StringArray is a wrapper for an array of strings.
@@ -492,9 +498,13 @@ type Build struct {
 	ID              string          `yaml:"id,omitempty" json:"id,omitempty"`
 	Goos            []string        `yaml:"goos,omitempty" json:"goos,omitempty"`
 	Goarch          []string        `yaml:"goarch,omitempty" json:"goarch,omitempty"`
-	Goarm           []string        `yaml:"goarm,omitempty" json:"goarm,omitempty"`
-	Gomips          []string        `yaml:"gomips,omitempty" json:"gomips,omitempty"`
 	Goamd64         []string        `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
+	Go386           []string        `yaml:"go386,omitempty" json:"go386,omitempty"`
+	Goarm           []string        `yaml:"goarm,omitempty" json:"goarm,omitempty"`
+	Goarm64         []string        `yaml:"goarm64,omitempty" json:"goarm64,omitempty"`
+	Gomips          []string        `yaml:"gomips,omitempty" json:"gomips,omitempty"`
+	Goppc64         []string        `yaml:"goppc64,omitempty" json:"goppc64,omitempty"`
+	Goriscv64       []string        `yaml:"goriscv64,omitempty" json:"goriscv64,omitempty"`
 	Targets         []string        `yaml:"targets,omitempty" json:"targets,omitempty"`
 	Ignore          []IgnoredBuild  `yaml:"ignore,omitempty" json:"ignore,omitempty"`
 	Dir             string          `yaml:"dir,omitempty" json:"dir,omitempty"`
@@ -518,9 +528,13 @@ type Build struct {
 type BuildDetailsOverride struct {
 	Goos         string `yaml:"goos,omitempty" json:"goos,omitempty"`
 	Goarch       string `yaml:"goarch,omitempty" json:"goarch,omitempty"`
+	Goamd64      string `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
+	Go386        string `yaml:"go386,omitempty" json:"go386,omitempty"`
+	Goarm64      string `yaml:"goarm64,omitempty" json:"goarm64,omitempty"`
 	Goarm        string `yaml:"goarm,omitempty" json:"goarm,omitempty" jsonschema:"oneof_type=string;integer"`
 	Gomips       string `yaml:"gomips,omitempty" json:"gomips,omitempty"`
-	Goamd64      string `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
+	Goppc64      string `yaml:"goppc64,omitempty" json:"goppc64,omitempty"`
+	Goriscv64    string `yaml:"goriscv64,omitempty" json:"goriscv64,omitempty"`
 	BuildDetails `yaml:",inline" json:",inline"`
 }
 
